package
module
Version:
v0.0.0-...-dfff267
Opens a new window with list of versions in this module.
Published: Dec 30, 2018
License: MIT
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
README
¶
goXmlParser
parses an xml file
Use it for large XML files like Open Street Maps files greater than 1000MB.
Documentation
¶
type Attribute struct {
}
Attribute
Source Files
¶
Click to show internal directories.
Click to hide internal directories.